using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Microsoft.WindowsCE.Forms;//for HardwareButtons and Keys

namespace ImageViewerPPC
{
    public partial class Form1 : Form
    {
        HardwareButton weightOn, weightOff;
        String onTitle = "Weight ON";
        String offTitle = "Weight OFF";

        private Image theImage;

        int lastX = 0, lastY = 0;
        int pressedX, pressedY;
        int offsetX = 0, offsetY = 0;
        //int imageAngle = 0;
        Boolean isPenDown = false;
        Boolean isPaperweightOn = false;
        Boolean hasImageDoodled = false;
        Pen myPen = new Pen(Color.Blue, 3);
        Graphics bufferG=null, displayG=null; //Graphics for buffer and display

        public Form1()
        {
            InitializeComponent();
            displayG = this.CreateGraphics();
            //prepare hardware buttons
            try
            {
                weightOn = new HardwareButton();
                weightOn.AssociatedControl = this;
                weightOn.HardwareKey = HardwareKeys.ApplicationKey2;
                weightOff = new HardwareButton();
                weightOff.AssociatedControl = this;
                weightOff.HardwareKey = HardwareKeys.ApplicationKey3;
            }
            catch (Exception exc)
            {
                MessageBox.Show(exc.Message + " Check if the hardware " +
                    "button is physically available on this device.");
            }
        }

        private void menuClose_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void menuOpen_Click(object sender, EventArgs e)
        {
            if (null != bufferG) bufferG.Dispose();
            if (DialogResult.OK == openFileDialog1.ShowDialog())
            {
                //MessageBox.Show(openFileDialog1.FileName);
                theImage = new Bitmap(openFileDialog1.FileName);
                bufferG = Graphics.FromImage(theImage);
            }
        }

        private void Form1_Click(object sender, EventArgs e)
        {
            //System.Drawing.Point boxLocation;
            //boxLocation = pictureBox1.Location;
            //boxLocation.Offset(-50, -50);
            //pictureBox1.Location = boxLocation;
            //this.pictureBox1.Location = new System.Drawing.Point(-50, -50);
            //pictureBox1.Location.Offset(-50, -50);
        }

        private Boolean doodleTo(int x, int y)
        {
            if (false == this.isPaperweightOn) return false;
            if (false == this.isPenDown) return false;
            //if (false == this.isDoodleDemo) return;
            //bufferGraphics.setColor(currentColor);
            //bufferGraphics.drawLine
            //((int)((lastX - offsetX) / zoomRatio), (int)((lastY - offsetY) / zoomRatio),
            //(int)((x - offsetX) / zoomRatio), (int)((y - offsetY) / zoomRatio));
            //Graphics g = Graphics.FromImage(theImage);
            displayG.DrawLine(myPen, lastX, lastY, x, y);
            bufferG.DrawLine(myPen, lastX-offsetX, lastY-offsetY, x-offsetX, y-offsetY);
            //g.Dispose();
            return true;
        }

        private Boolean scrollTo(int x, int y)
        {
            if (this.isPaperweightOn) return false;//do nothing
            offsetX += x - lastX;
            offsetY += y - lastY;
            if (offsetX > 0) offsetX = 0;
            if (offsetY > 0) offsetY = 0;
            int minOffsetX = -theImage.Width + this.Width;
            int minOffsetY = -theImage.Height + this.Height;
            if (offsetX < minOffsetX) offsetX = minOffsetX;
            if (offsetY < minOffsetY) offsetY = minOffsetY;

            //displayG.GetHdc();
            return true;
        }

        private void Form1_MouseMove(object sender, MouseEventArgs e)
        {
            Boolean hasScrolled = false, hasDoodled = false;
            int x, y, top, left, width, height;
            x = e.X; y = e.Y;
            hasScrolled = this.scrollTo(x, y);//scroll if needed
            hasDoodled = this.doodleTo(x, y);//doodle if needed
            hasImageDoodled |= hasDoodled;
            left = Math.Min(x, lastX);
            top = Math.Min(y, lastY);
            width = Math.Abs(x - lastX);
            height = Math.Abs(y - lastY);
            lastX = x; lastY = y;
            if(hasScrolled) this.Invalidate();
            //this.Invalidate(new Rectangle(left,top,width,height));
        }

        private void Form1_MouseDown(object sender, MouseEventArgs e)
        {
            pressedX = e.X; pressedY = e.Y;
            lastX = pressedX; lastY = pressedY;
            isPenDown = true;
            if (this.isPaperweightOn) this.hasImageDoodled = true;
            else this.hasImageDoodled = false;
        }

        private void Form1_MouseUp(object sender, MouseEventArgs e)
        {

            isPenDown = false;
          
            if (hasImageDoodled)
            {
                this.Invalidate();
                hasImageDoodled = false;
            }
        }

        private void Form1_Paint(object sender, PaintEventArgs e)
        {
            if(null!=theImage)
            {
                //int x,y,w,h;
                //x=e.ClipRectangle.X;
                //y = e.ClipRectangle.Y;
                //w = e.ClipRectangle.Width;
                //h = e.ClipRectangle.Height;
                e.Graphics.DrawImage(theImage, offsetX, offsetY);
            }
        }

        private void Form1_KeyDown(object sender, KeyEventArgs e)
        {
            isPaperweightOn = true;

            if ((e.KeyCode == System.Windows.Forms.Keys.Up))
            {
                // bJ[
                // 
                //MessageBox.Show("keys.up");
            }
            if ((e.KeyCode == System.Windows.Forms.Keys.Down))
            {
                // bJ[
                // 
            }
            if ((e.KeyCode == System.Windows.Forms.Keys.Left))
            {
                // 
            }
            if ((e.KeyCode == System.Windows.Forms.Keys.Right))
            {
                // E
            }
            if ((e.KeyCode == System.Windows.Forms.Keys.Enter))
            {
                // 
                //MessageBox.Show("keys.enter");
            }

        }

        private void Form1_KeyPress(object sender, KeyPressEventArgs e)
        {
            //MessageBox.Show("keys.press");
        }

        private void Form1_KeyUp(object sender, KeyEventArgs e)
        {
            isPaperweightOn = false;//for usb keyboard

            if ((HardwareKeys)e.KeyCode == weightOn.HardwareKey)
            {
                //MessageBox.Show("weightOn");
                this.Text = onTitle;
                //this.Capture = false;
                this.isPaperweightOn = true;
            }
            if ((HardwareKeys)e.KeyCode == weightOff.HardwareKey)
            {
                //MessageBox.Show("weightOff");
                this.Text = offTitle;
                //this.Capture = true;
                this.isPaperweightOn = false;
            }
        }


    }
}